@@ -1,8 +1,10 @@
+import typing as t
 from abc import ABC, abstractmethod
 from collections.abc import Iterable
+from copy import copy
 from pathlib import Path, PosixPath
 from typing import Union
-from copy import copy
+
 from yaml import dump, safe_load
 
 
@@ -15,15 +17,15 @@ class ParametersABC(ABC):
     """
 
     def __init__(self, **kwargs):
-        '''
+        """
         Defines parameters as attributes
-        '''
-        assert "parameters" not in kwargs, "No attribute should be named parameters"
+        """
+        assert (
+            "parameters" not in kwargs
+        ), "No attribute should be named parameters"
         for k, v in kwargs.items():
             setattr(self, k, v)
 
-    ###
-
     def to_dict(self, iterable="null"):
         """
         Recursive function to return a nested dictionary of the
@@ -38,7 +40,9 @@ class ParametersABC(ABC):
                 ]
             ):
                 return {
-                    k: v.to_dict() if hasattr(v, "to_dict") else self.to_dict(v)
+                    k: v.to_dict()
+                    if hasattr(v, "to_dict")
+                    else self.to_dict(v)
                     for k, v in iterable.items()
                 }
             else:
@@ -64,8 +68,6 @@ class ParametersABC(ABC):
                 dump(self.to_dict(), f)
         return dump(self.to_dict())
 
-    ###
-
     @classmethod
     def from_dict(cls, d: dict):
         return cls(**d)
@@ -79,7 +81,7 @@ class ParametersABC(ABC):
         try:
             if Path(source).exists():
                 is_buffer = False
-        except:
+        except Exception:
             pass
         if is_buffer:
             params = safe_load(source)
@@ -95,7 +97,32 @@ class ParametersABC(ABC):
             overriden_defaults[k] = v
         return cls.from_dict(overriden_defaults)
 
-###
+    def update(self, name: str, new_value):
+        """
+        Update values recursively
+        if name is a dictionary, inject data where found.
+        It forbids type changes.
+
+
+        """
+
+        assert name not in (
+            "parameters",
+            "params",
+        ), "Attribute can't be named params or parameters"
+
+        if name in self.__dict__:
+            assert check_type_recursive(
+                getattr(self, name), new_value
+            ), "Type changes are not valid"
+
+            if isinstance(getattr(self, name), dict):
+                new_d = getattr(self, name)
+                new_d.update(new_value)
+                setattr(self, name, new_d)
+
+        else:
+            setattr(self, name, new_value)
 
 
 class ProcessABC(ABC):
@@ -123,3 +150,23 @@ class ProcessABC(ABC):
     @abstractmethod
     def run(self):
         pass
+
+
+def check_type_recursive(val1, val2):
+    same_types = True
+    if not isinstance(val1, type(val2)) and not all(
+        type(x) in (PosixPath, str) for x in (val1, val2)  # Ignore str->path
+    ):
+        return False
+    if not isinstance(val1, t.Iterable) and not isinstance(val2, t.Iterable):
+        return isinstance(val1, type(val2))
+    elif isinstance(val1, (tuple, list)) and isinstance(val2, (tuple, list)):
+        return bool(
+            sum([check_type_recursive(v1, v2) for v1, v2 in zip(val1, val2)])
+        )
+    elif isinstance(val1, dict) and isinstance(val2, dict):
+        if not len(val1) or not len(val2):
+            return False
+        for k in val2.keys():
+            same_types = same_types and check_type_recursive(val1[k], val2[k])
+    return same_types
