@@ -63,9 +63,11 @@ class Parser(object):
 
         self._triggers = {
             trigger_type: [
-                (k, v[trigger_type])
+                (k, v[f"trigger_{trigger_type}"])
+                if trigger_type != "re"
+                else (k, re.compile(v[f"trigger_{trigger_type}"]))
                 for k, v in self.grammar.items()
-                if "_".join("trigger", trigger_type) in v
+                if f"trigger_{trigger_type}" in v
             ]
             for trigger_type in ("startswith", "endswith", "contains", "re")
         }
@@ -111,24 +113,28 @@ class Parser(object):
                         lambda x, t: x.startswith(t),
                         lambda x, t: x.endswith(t),
                         lambda x, t: x.find(t),
-                        lambda x, t: t.findall(x),
+                        lambda x, re: re.findall(x),
                     ),
                 )
             }
             matches = {
                 trigger: [
-                    (k, t)
-                    for k, t in self._triggers[trigger]
+                    (k, trig_str)
+                    for k, trig_str in self._triggers[trigger]
                     if any(
                         [
-                            trigger_check_methods[trigger](line, t)
+                            trigger_check_methods[trigger](line, trig_str)
                             for line in line_pp
                         ]
                     )
                 ]
                 for trigger, method in trigger_check_methods.items()
             }
-            section_match = {k for trigger_matches in matches for k in matches}
+            section_match = {
+                k
+                for trigger_matches in matches.values()
+                for k, _ in trigger_matches
+            }
 
             # if len(section_match) > 1:
             assert len(section_match) <= 1, ParseError(
@@ -140,7 +146,9 @@ class Parser(object):
                 self._set_section(list(section_match)[0])
 
                 # Determine the unmatched part of the line
-                line_unmatched = self.determine_unmatched(matches, line_pp)
+                line_unmatched = self.determine_unmatched_part(
+                    matches, line_pp
+                )
 
                 # Skip the matched line if requested
                 if self._active_section.get(
@@ -169,7 +177,12 @@ class Parser(object):
 
                 if section_name not in output:
                     # Table needs initialisation
-                    table_header = self._parse_table(active_section, row)
+                    (
+                        has_header,
+                        row,
+                        table_header,
+                        column_types,
+                    ) = self._parse_table(active_section, row)
 
                     output[section_name] = {k: [] for k in table_header}
 
@@ -196,7 +209,7 @@ class Parser(object):
 
             elif section_type in {"list", "lists"}:
                 sep = active_section.get("separator", ",")
-                output[section_name] = output.get(output[section_name], [])
+                output[section_name] = output.get(section_name, [])
 
                 map_type = active_section.get("map")
                 next_list = [
@@ -232,13 +245,17 @@ class Parser(object):
 
             else:
                 # By default, just append additional lines as text
-                str_to_append = "\n" + line if section_name in output else line
-                output[section_name] += str_to_append
+                new_str = (
+                    f"{output[section_name]}\n{line}"
+                    if section_name in output
+                    else line
+                )
+                output[section_name] = new_str
 
         return output
 
     @staticmethod
-    def determine_umatched_part(
+    def determine_unmatched_part(
         matches: t.Dict[str, t.List], line_pp: t.List[str]
     ):
 
@@ -302,7 +319,7 @@ class Parser(object):
             ]
         else:
             raise ParseError("badly formatted column map")
-        return table_header
+        return has_header, row, table_header, column_types
 
     @staticmethod
     def _table_merge_extra_columns(table_header, sep, row, column_types):
